library(PASSED)

power_Beta(
  mu1 = 0.0174, sd1 = 0.0211, mu2 = 0.0120, power = 0.8,
  link.type = "logit", trials = 1000, equal.precision = TRUE
)

# Set seed for the simulation below
set.seed(1)
Ex1 <- mapply(
  function(mu2, sample_size) {
    Betapower <- power_Beta(
      mu1 = 0.0174, sd1 = 0.0211,
      mu2 = mu2, n1 = sample_size,
      link.type = "logit", trials = 1000, equal.precision = TRUE
    )
    Proppower <- power_Normal(delta = (0.0174 - mu2), n1 = sample_size, sd1 = 0.0211, sd2 = 0.0211)
    return(c(Betapower$power, round(Proppower$power, 3), sample_size, mu2, 0.0174))
  },
  # Range of mu2 was set as [0.0120, 0.0140] by 0.0010
  rep(seq(0.0120, 0.0140, 0.0010), 5),
  # Rnage of sample size was set as [100, 200] by 25
  rep(seq(100, 200, 25), rep(3, 5))
)
# Reform the output
Ex1 <- as.data.frame(t(Ex1))
# Set column names
colnames(Ex1) <- c("Power (Beta)", "Power (Normal)", "Sample Size", "mu2", "mu1")


# Set seed for the simulation below
Ex1_ne <- mapply(
  function(mu2, sample_size) {
    Betapower <- power_Beta(
      mu1 = 0.0174, sd1 = 0.0211, sd2 = 0.030,
      mu2 = mu2, n1 = sample_size,
      link.type = "logit", trials = 1000, equal.precision = FALSE
    )
    Proppower <- power_Normal(delta = (0.0174 - mu2), n1 = sample_size, sd1 = 0.0211, sd2 = 0.030)
    return(c(Betapower$power, round(Proppower$power, 3), sample_size, mu2))
  },
  # Range of mu2 was set as [0.0120, 0.0140] by 0.0010
  rep(seq(0.0120, 0.0140, 0.0010), 5),
  # Rnage of sample size was set as [100, 200] by 25
  rep(seq(100, 200, 25), rep(3, 5))
)
# Reform the output
Ex1_ne <- as.data.frame(t(Ex1_ne))
# Set column names
colnames(Ex1_ne) <- c("Power (Beta)", "Power (Normal)", "Sample Size", "mu2")
# Add a column of mu1
Ex1_ne$mu1 <- rep(0.0174, nrow(Ex1_ne))

# graphic
par(mfrow = c(1, 2))

mu1 <- 0.0174
mu2 <- 0.0120
sd1 <- 0.0211
sd2 <- 0.0300
phi <- ((mu1 * (1 - mu1)) / (sd1 * sd1)) - 1
a0 <- mu1 * phi
b0 <- (1 - mu1) * phi
a1 <- mu2 * phi
b1 <- (1 - mu2) * phi

Ex1_eq_p_1 <- sapply(seq(0.001, 0.100, 0.001), function(i) {
  return(dbeta(i, a0, b0))
})
plot(seq(0.001, 0.100, 0.001), Ex1_eq_p_1,
  xlab = "percentage of SNF residents with pressure ulcers", ylab = "density", type = "l", xlim = c(-0.001, 0.10), main = "equal precision or standard deviation",
  col = "#1E90FF", lwd = 3, lty = 1
)
Ex1_eq_p_2 <- sapply(seq(0.001, 0.100, 0.001), function(i) {
  return(dbeta(i, a1, b1))
})
lines(seq(0.001, 0.100, 0.001), Ex1_eq_p_2, col = "#1E90FF", lwd = 3, lty = 2)
Ex1_nm_p_1 <- sapply(seq(-0.00, 0.100, 0.001), function(i) {
  return(dnorm(i, mu1, sd1))
})
lines(seq(-0.00, 0.100, 0.001), Ex1_nm_p_1, col = "#FF8C00", lwd = 3)
Ex1_nm_p_2 <- sapply(seq(-0.00, 0.100, 0.001), function(i) {
  return(dnorm(i, mu2, sd1))
})
lines(seq(-0.00, 0.100, 0.001), Ex1_nm_p_2, col = "#FF8C00", lwd = 3, lty = 2)
polygon(c(seq(0.001, 0.100, 0.001), rev(seq(0.001, 0.100, 0.001))), c(Ex1_eq_p_2, rev(Ex1_eq_p_1)), col = rgb(135/255,206/255,250/255,0.8), border = NA)
polygon(c(seq(-0.00, 0.100, 0.001), rev(seq(-0.00, 0.100, 0.001))), c(Ex1_nm_p_1, rev(Ex1_nm_p_2)), col = rgb(255/255,127/255,80/255,0.2), border = NA)

legend(0.050, 80, c("Beta (control)", "Beta (treatment)", "Normal (control)", "Normal (treatment)"), lty = c(1, 2, 1, 3), col = c("#1E90FF", "#1E90FF", "#FF8C00", "#FF8C00"), lwd = c(3, 3, 3, 3))

mu1 <- 0.0174
mu2 <- 0.0120
sd1 <- 0.0211
sd2 <- 0.0300
phi <- ((mu1 * (1 - mu1)) / (sd1 * sd1)) - 1
phi1 <- ((mu2 * (1 - mu2)) / (sd2 * sd2)) - 1
a0 <- mu1 * phi
b0 <- (1 - mu1) * phi
a1 <- mu2 * phi1
b1 <- (1 - mu2) * phi1

Ex1_ne_p_1 <- sapply(seq(0.001, 0.100, 0.001), function(i) {
  return(dbeta(i, a0, b0))
})
plot(seq(0.001, 0.100, 0.001), Ex1_ne_p_1,
  xlab = "percentage of SNF residents with pressure ulcers", ylab = "density", type = "l", xlim = c(-0.001, 0.10), main = "unequal precision or standard deviation",
  col = "#1E90FF", lwd = 3, lty = 1
)
Ex1_ne_p_2 <- sapply(seq(0.001, 0.100, 0.001), function(i) {
  return(dbeta(i, a1, b1))
})
lines(seq(0.001, 0.100, 0.001), Ex1_ne_p_2, col = "#1E90FF", lwd = 3, lty = 2)
Ex1_nm_p_1 <- sapply(seq(-0.00, 0.100, 0.001), function(i) {
  return(dnorm(i, mu1, sd1))
})
lines(seq(-0.00, 0.100, 0.001), Ex1_nm_p_1, col = "#FF8C00", lwd = 3)
Ex1_nm_p_2 <- sapply(seq(-0.00, 0.100, 0.001), function(i) {
  return(dnorm(i, mu2, sd2))
})
lines(seq(-0.00, 0.100, 0.001), Ex1_nm_p_2, col = "#FF8C00", lwd = 3, lty = 2)
polygon(c(seq(0.001, 0.100, 0.001), rev(seq(0.001, 0.100, 0.001))), c(Ex1_ne_p_2, rev(Ex1_ne_p_1)), col = rgb(135/255, 206/255, 250/255, 0.8), border = NA)
polygon(c(seq(-0.00, 0.100, 0.001), rev(seq(-0.00, 0.100, 0.001))), c(Ex1_nm_p_1, rev(Ex1_nm_p_2)), col = rgb(255/255, 127/255, 80/255, 0.2), border = NA)

legend(0.050, 80, c("Beta (control)", "Beta (treatment)", "Normal (control)", "Normal (treatment)"), lty = c(1, 2, 1, 3), col = c("#1E90FF", "#1E90FF", "#FF8C00", "#FF8C00"), lwd = c(3, 3, 3, 3))

par(mfrow = c(1, 1))

# Ex2_data <- data.frame(Well = c(rep("S",41),rep("H",17)),
#                       yield = c(0.22, 1.33, 0.75, 0.18,
#                                 0.01, 0.16, 0.28, 0.87,
#                                 0.02, 0.10, 0.03, 0.05,
#                                 0.86, 5.00, 0.04, 4.00,
#                                 0.37, 0.38, 0.11, 0.10,
#                                 0.02, 0.01, 0.05, 0.17,
#                                 0.46, 0.16, 1.33, 0.14,
#                                 2.86, 0.13, 7.50, 4.50,
#                                 0.03, 0.003, 0.05, 0.02,
#                                 0.04, 0.75, 0.52, 5.00,
#                                 0.35,
#                                 0.12, 0.15, 0.03, 0.08,
#                                 0.07, 0.12, 0.01, 0.03,
#                                 0.02, 0.01, 1.94, 0.21,
#                                 0.06, 0.83, 0.15, 0.10,
#                                 0.14))

# aggregate(Ex2_data$yield, list(Ex2_data$Well), "mean")
# aggregate(Ex2_data$yield, list(Ex2_data$Well), function(i) exp(mean(log(i))))
# set.seed(1)
# power_Gamma(n1 = 41, n2 = 17, mu1 = 0.2394, mu2 = 0.9501, gmu1 = 0.0869, gmu2 = 0.2023, M = 1e5)
# power_Normal(n1 = 41, n2 = 17, delta = -0.7107, sd1 = 0.4772, sd2 = 1.7395)
